**Example 1: DescribeCustomer**



Input: 

```
tccli solar DescribeCustomer --cli-unfold-argument  \
    --UserId 659051925723025408
```

Output: 
```
{
    "Response": {
        "RequestId": "7483b380-5eeb-485b-bd3a-0b7ae62e4d55",
        "AddressList": null,
        "UserId": "659051925723025408",
        "Avatar": "http://thirdwx.qlogo.cn/mmopen/vi_32/PiajxSqBRHtKic20343dJ7AWNRoQ/132",
        "Birthday": "2010-10-10",
        "City": "深圳",
        "CreateTime": 1577171824000,
        "Device": "9.0.2524.400",
        "Industrys": "",
        "LastActiveTime": 1577675316573,
        "MarkFlag": 0,
        "Model": "qq",
        "OpenId": "o5Kw21t6M7TCFrT96ZQ_Qn2Pz4vQ",
        "PayFeature": "",
        "Phone": "",
        "PhoneList": "",
        "Province": "广东",
        "RealName": null,
        "RelChannelFlag": null,
        "Remark": null,
        "Sex": 1,
        "SourceAudienceVo": null,
        "SubWechats": null,
        "UnionId": "odreBwax7AzElvM2R1QNTYxqs6kE",
        "UpdateTime": 1577675320000,
        "UserTypes": null,
        "WxCity": "深圳",
        "WxCountry": "中国",
        "WxNickname": "槐",
        "WxProvince": "广东"
    }
}
```

